==> altsys-0.3.zip: xoops_trust_path/libs/altsys/language/english/modinfo.php <==
<?php

define( '_MI_ALTSYS_MODULENAME' , 'ALTSYS' ) ;
define( '_MI_ALTSYS_MODULEDESC' , 'Managing system easily' ) ;

define( '_MI_ALTSYS_MENU_CUSTOMBLOCKS' , 'Custom Blocks' ) ;
define( '_MI_ALTSYS_MENU_NEWCUSTOMBLOCK' , '(new)' ) ;
define( '_MI_ALTSYS_MENU_MYBLOCKSADMIN' , 'Module Blocks' ) ;
define( '_MI_ALTSYS_MENU_MYTPLSADMIN' , 'Templates' ) ;
define( '_MI_ALTSYS_MENU_COMPILEHOOKADMIN' , 'Advanced Templates' ) ;
define( '_MI_ALTSYS_MENU_MYAVATAR' , 'Avatars' ) ;
define( '_MI_ALTSYS_MENU_MYSMILEY' , 'Smileys' ) ;

define( '_MI_ALTSYS_ADMINMENU_HFT' , 'Rewrite admin menu' ) ;
define( '_MI_ALTSYS_ADMINMENU_HFTDSC' , 'If your admin menu is broken, remove cache/adminmenu.php. This feature works only with XOOPS 2.0.x' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_2COL' , 'Two columns of module icons' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_NOIMG' , 'IMG to TEXT' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_XCSTY' , 'Like XoopsCube Legacy 2.1' ) ;

define( '_MI_ALTSYS_ADMINMENU_IM' , 'Copy mymenu links into admin menu' ) ;
define( '_MI_ALTSYS_ADMINMENU_IMDSC' , 'If your admin menu is broken, remove cache/adminmenu.php. This feature works only with XOOPS 2.0.x' ) ;

define( '_MI_ALTSYS_ADMIN_IN_THEME' , 'Theme set for admin' ) ;
define( '_MI_ALTSYS_ADMIN_IN_THEMEDSC' , 'Set the name of the theme displaying admin area. Insert a line just after including common.php in mainfile.php<br />include XOOPS_TRUST_PATH.\'/libs/altsys/include/admin_in_theme.inc.php\';<br /> to enable this. This feature works only with XOOPS 2.0.x' ) ;


?>

==> altsys-0.4.zip: xoops_trust_path/libs/altsys/language/english/modinfo.php <==
<?php

define( '_MI_ALTSYS_MODULENAME' , 'ALTSYS' ) ;
define( '_MI_ALTSYS_MODULEDESC' , 'Managing system easily' ) ;

// menus
define( '_MI_ALTSYS_MENU_CUSTOMBLOCKS' , 'Custom Blocks' ) ;
define( '_MI_ALTSYS_MENU_NEWCUSTOMBLOCK' , '(new)' ) ;
define( '_MI_ALTSYS_MENU_MYBLOCKSADMIN' , 'Module Blocks' ) ;
define( '_MI_ALTSYS_MENU_MYTPLSADMIN' , 'Templates' ) ;
define( '_MI_ALTSYS_MENU_COMPILEHOOKADMIN' , 'Advanced Templates' ) ;
define( '_MI_ALTSYS_MENU_MYAVATAR' , 'Avatars' ) ;
define( '_MI_ALTSYS_MENU_MYSMILEY' , 'Smileys' ) ;

// blocks
define( '_MI_ALTSYS_BNAME_ADMIN_MENU' , 'Admin Menu' ) ;

// configs
define( '_MI_ALTSYS_ADMINMENU_HFT' , 'Rewrite admin menu' ) ;
define( '_MI_ALTSYS_ADMINMENU_HFTDSC' , 'If your admin menu is broken, remove cache/adminmenu.php. This feature works only with XOOPS 2.0.x' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_2COL' , 'Two columns of module icons' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_NOIMG' , 'IMG to TEXT' ) ;
define( '_MI_ALTSYS_AMHFT_OPT_XCSTY' , 'Like XoopsCube Legacy 2.1' ) ;

define( '_MI_ALTSYS_ADMINMENU_IM' , 'Copy mymenu links into admin menu' ) ;
define( '_MI_ALTSYS_ADMINMENU_IMDSC' , 'If your admin menu is broken, remove cache/adminmenu.php. This feature works only with XOOPS 2.0.x' ) ;

define( '_MI_ALTSYS_ADMIN_IN_THEME' , 'Theme set for admin' ) ;
define( '_MI_ALTSYS_ADMIN_IN_THEMEDSC' , 'Set the name of the theme displaying admin area. Insert a line just after including common.php in mainfile.php<br />include XOOPS_TRUST_PATH.\'/libs/altsys/include/admin_in_theme.inc.php\';<br /> to enable this. This feature works only with XOOPS 2.0.x' ) ;

define( '_MI_ALTSYS_IMAGES_DIR','Directory for image files');
define( '_MI_ALTSYS_IMAGES_DIRDSC','relative path should be set in the module directory. default: images');

?>
